@@ -86,7 +86,7 @@ class SecretsManagerClient:
         KmsKeyId: str = None,
         SecretBinary: Union[bytes, IO] = None,
         SecretString: str = None,
-        Tags: List[TagTypeDef] = None,
+        Tags: List["TagTypeDef"] = None,
     ) -> CreateSecretResponseTypeDef:
         """
         [Client.create_secret documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/secretsmanager.html#SecretsManager.Client.create_secret)
@@ -197,13 +197,13 @@ class SecretsManagerClient:
         SecretId: str,
         ClientRequestToken: str = None,
         RotationLambdaARN: str = None,
-        RotationRules: RotationRulesTypeTypeDef = None,
+        RotationRules: "RotationRulesTypeTypeDef" = None,
     ) -> RotateSecretResponseTypeDef:
         """
         [Client.rotate_secret documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/secretsmanager.html#SecretsManager.Client.rotate_secret)
         """
 
-    def tag_resource(self, SecretId: str, Tags: List[TagTypeDef]) -> None:
+    def tag_resource(self, SecretId: str, Tags: List["TagTypeDef"]) -> None:
         """
         [Client.tag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/secretsmanager.html#SecretsManager.Client.tag_resource)
         """
