@@ -3,9 +3,9 @@ Main interface for secretsmanager service type definitions.
 
 Usage::
 
-    from mypy_boto3.secretsmanager.type_defs import CancelRotateSecretResponseTypeDef
+    from mypy_boto3.secretsmanager.type_defs import RotationRulesTypeTypeDef
 
-    data: CancelRotateSecretResponseTypeDef = {...}
+    data: RotationRulesTypeTypeDef = {...}
 """
 from datetime import datetime
 import sys
@@ -18,19 +18,19 @@ else:
 
 
 __all__ = (
+    "RotationRulesTypeTypeDef",
+    "SecretListEntryTypeDef",
+    "SecretVersionsListEntryTypeDef",
+    "TagTypeDef",
     "CancelRotateSecretResponseTypeDef",
     "CreateSecretResponseTypeDef",
     "DeleteResourcePolicyResponseTypeDef",
     "DeleteSecretResponseTypeDef",
-    "RotationRulesTypeTypeDef",
-    "TagTypeDef",
     "DescribeSecretResponseTypeDef",
     "GetRandomPasswordResponseTypeDef",
     "GetResourcePolicyResponseTypeDef",
     "GetSecretValueResponseTypeDef",
-    "SecretVersionsListEntryTypeDef",
     "ListSecretVersionIdsResponseTypeDef",
-    "SecretListEntryTypeDef",
     "ListSecretsResponseTypeDef",
     "PaginatorConfigTypeDef",
     "PutResourcePolicyResponseTypeDef",
@@ -41,6 +41,44 @@ __all__ = (
     "UpdateSecretVersionStageResponseTypeDef",
 )
 
+RotationRulesTypeTypeDef = TypedDict(
+    "RotationRulesTypeTypeDef", {"AutomaticallyAfterDays": int}, total=False
+)
+
+SecretListEntryTypeDef = TypedDict(
+    "SecretListEntryTypeDef",
+    {
+        "ARN": str,
+        "Name": str,
+        "Description": str,
+        "KmsKeyId": str,
+        "RotationEnabled": bool,
+        "RotationLambdaARN": str,
+        "RotationRules": "RotationRulesTypeTypeDef",
+        "LastRotatedDate": datetime,
+        "LastChangedDate": datetime,
+        "LastAccessedDate": datetime,
+        "DeletedDate": datetime,
+        "Tags": List["TagTypeDef"],
+        "SecretVersionsToStages": Dict[str, List[str]],
+        "OwningService": str,
+    },
+    total=False,
+)
+
+SecretVersionsListEntryTypeDef = TypedDict(
+    "SecretVersionsListEntryTypeDef",
+    {
+        "VersionId": str,
+        "VersionStages": List[str],
+        "LastAccessedDate": datetime,
+        "CreatedDate": datetime,
+    },
+    total=False,
+)
+
+TagTypeDef = TypedDict("TagTypeDef", {"Key": str, "Value": str}, total=False)
+
 CancelRotateSecretResponseTypeDef = TypedDict(
     "CancelRotateSecretResponseTypeDef", {"ARN": str, "Name": str, "VersionId": str}, total=False
 )
@@ -57,12 +95,6 @@ DeleteSecretResponseTypeDef = TypedDict(
     "DeleteSecretResponseTypeDef", {"ARN": str, "Name": str, "DeletionDate": datetime}, total=False
 )
 
-RotationRulesTypeTypeDef = TypedDict(
-    "RotationRulesTypeTypeDef", {"AutomaticallyAfterDays": int}, total=False
-)
-
-TagTypeDef = TypedDict("TagTypeDef", {"Key": str, "Value": str}, total=False)
-
 DescribeSecretResponseTypeDef = TypedDict(
     "DescribeSecretResponseTypeDef",
     {
@@ -72,12 +104,12 @@ DescribeSecretResponseTypeDef = TypedDict(
         "KmsKeyId": str,
         "RotationEnabled": bool,
         "RotationLambdaARN": str,
-        "RotationRules": RotationRulesTypeTypeDef,
+        "RotationRules": "RotationRulesTypeTypeDef",
         "LastRotatedDate": datetime,
         "LastChangedDate": datetime,
         "LastAccessedDate": datetime,
         "DeletedDate": datetime,
-        "Tags": List[TagTypeDef],
+        "Tags": List["TagTypeDef"],
         "VersionIdsToStages": Dict[str, List[str]],
         "OwningService": str,
     },
@@ -108,47 +140,15 @@ GetSecretValueResponseTypeDef = TypedDict(
     total=False,
 )
 
-SecretVersionsListEntryTypeDef = TypedDict(
-    "SecretVersionsListEntryTypeDef",
-    {
-        "VersionId": str,
-        "VersionStages": List[str],
-        "LastAccessedDate": datetime,
-        "CreatedDate": datetime,
-    },
-    total=False,
-)
-
 ListSecretVersionIdsResponseTypeDef = TypedDict(
     "ListSecretVersionIdsResponseTypeDef",
-    {"Versions": List[SecretVersionsListEntryTypeDef], "NextToken": str, "ARN": str, "Name": str},
-    total=False,
-)
-
-SecretListEntryTypeDef = TypedDict(
-    "SecretListEntryTypeDef",
-    {
-        "ARN": str,
-        "Name": str,
-        "Description": str,
-        "KmsKeyId": str,
-        "RotationEnabled": bool,
-        "RotationLambdaARN": str,
-        "RotationRules": RotationRulesTypeTypeDef,
-        "LastRotatedDate": datetime,
-        "LastChangedDate": datetime,
-        "LastAccessedDate": datetime,
-        "DeletedDate": datetime,
-        "Tags": List[TagTypeDef],
-        "SecretVersionsToStages": Dict[str, List[str]],
-        "OwningService": str,
-    },
+    {"Versions": List["SecretVersionsListEntryTypeDef"], "NextToken": str, "ARN": str, "Name": str},
     total=False,
 )
 
 ListSecretsResponseTypeDef = TypedDict(
     "ListSecretsResponseTypeDef",
-    {"SecretList": List[SecretListEntryTypeDef], "NextToken": str},
+    {"SecretList": List["SecretListEntryTypeDef"], "NextToken": str},
     total=False,
 )
 
